@@ -62,8 +62,8 @@ QJsonValue ModelVerificationPoint::variantToJson(const QVariant &v) const
             obj.remove(filter);
         }
         return obj;
-    } else if (v.userType() == qMetaTypeId<QVector<QVariant>>()) {
-        return KItinerary::JsonLdDocument::toJson(v.value<QVector<QVariant>>());
+    } else if (v.userType() == qMetaTypeId<QList<QVariant>>()) {
+      return KItinerary::JsonLdDocument::toJson(v.value<QList<QVariant>>());
     }
 
     return {};
@@ -101,7 +101,7 @@ bool ModelVerificationPoint::verify(QAbstractItemModel *model) const
 
     // compare
     if (array != refArray) {
-        QFile failFile(m_refFile + QLatin1String(".fail"));
+        QFile failFile(m_refFile + QLatin1StringView(".fail"));
         failFile.open(QFile::WriteOnly);
         failFile.write(QJsonDocument(array).toJson());
         failFile.close();
