@@ -39,9 +39,9 @@
 #include <QFile>
 #include <QJsonDocument>
 #include <QJsonObject>
+#include <QList>
 #include <QSettings>
 #include <QStandardPaths>
-#include <QVector>
 
 #include <cassert>
 
@@ -55,16 +55,16 @@ LiveDataManager::LiveDataManager(QObject *parent)
     , m_onboardStatus(new KPublicTransport::OnboardStatus(this))
 {
     QSettings settings;
-    settings.beginGroup(QLatin1String("KPublicTransport"));
-    m_ptMgr->setAllowInsecureBackends(settings.value(QLatin1String("AllowInsecureBackends"), false).toBool());
-    m_ptMgr->setDisabledBackends(settings.value(QLatin1String("DisabledBackends"), QStringList()).toStringList());
-    m_ptMgr->setEnabledBackends(settings.value(QLatin1String("EnabledBackends"), QStringList()).toStringList());
+    settings.beginGroup(QLatin1StringView("KPublicTransport"));
+    m_ptMgr->setAllowInsecureBackends(settings.value(QLatin1StringView("AllowInsecureBackends"), false).toBool());
+    m_ptMgr->setDisabledBackends(settings.value(QLatin1StringView("DisabledBackends"), QStringList()).toStringList());
+    m_ptMgr->setEnabledBackends(settings.value(QLatin1StringView("EnabledBackends"), QStringList()).toStringList());
     connect(m_ptMgr, &KPublicTransport::Manager::configurationChanged, this, [this]() {
         QSettings settings;
-        settings.beginGroup(QLatin1String("KPublicTransport"));
-        settings.setValue(QLatin1String("AllowInsecureBackends"), m_ptMgr->allowInsecureBackends());
-        settings.setValue(QLatin1String("DisabledBackends"), m_ptMgr->disabledBackends());
-        settings.setValue(QLatin1String("EnabledBackends"), m_ptMgr->enabledBackends());
+        settings.beginGroup(QLatin1StringView("KPublicTransport"));
+        settings.setValue(QLatin1StringView("AllowInsecureBackends"), m_ptMgr->allowInsecureBackends());
+        settings.setValue(QLatin1StringView("DisabledBackends"), m_ptMgr->disabledBackends());
+        settings.setValue(QLatin1StringView("EnabledBackends"), m_ptMgr->enabledBackends());
     });
 
     m_pollTimer.setSingleShot(true);
@@ -280,31 +280,6 @@ void LiveDataManager::journeyQueryFinished(KPublicTransport::JourneyReply *reply
     data(resId).setTimestamp(LiveData::Departure, now());
 }
 
-void LiveDataManager::updateStopoverData(const KPublicTransport::Stopover &stop, LiveData::Type type, const QString &resId, const QVariant &res)
-{
-    auto &ld = data(resId);
-    const auto oldStop = ld.stopover(type);
-    auto newStop = stop;
-    newStop.applyMetaData(true); // download logo assets if needed
-    ld.setStopover(type, newStop);
-    ld.setTimestamp(type, now());
-    ld.store(resId);
-
-    // update reservation with live data
-    const auto newRes = type == LiveData::Arrival ? PublicTransport::mergeArrival(res, newStop) : PublicTransport::mergeDeparture(res, newStop);
-    if (!ReservationHelper::equals(res, newRes)) {
-        m_resMgr->updateReservation(resId, newRes);
-    }
-
-    // emit update signals
-    Q_EMIT type == LiveData::Arrival ? arrivalUpdated(resId) : departureUpdated(resId);
-
-    // check if we need to notify
-    if (NotificationHelper::shouldNotify(oldStop, newStop, type)) {
-        showNotification(resId, ld);
-    }
-}
-
 static KPublicTransport::Stopover applyLayoutData(const KPublicTransport::Stopover &stop, const KPublicTransport::Stopover &layout)
 {
     auto res = stop;
@@ -327,6 +302,45 @@ static void applyMissingStopoverData(KPublicTransport::Stopover &stop, const KPu
     }
 }
 
+void LiveDataManager::updateStopoverData(const KPublicTransport::Stopover &stop, LiveData::Type type, const QString &resId, const QVariant &res)
+{
+    auto &ld = data(resId);
+    const auto oldStop = ld.stopover(type);
+    auto newStop = stop;
+    newStop.applyMetaData(true); // download logo assets if needed
+
+    // retain already existing vehicle/platform layout data if we are still departing/arriving in the same place
+    if (PublicTransport::isSameStopoverForLayout(newStop, oldStop)) {
+        newStop = applyLayoutData(newStop, oldStop);
+    }
+    applyMissingStopoverData(newStop, oldStop);
+
+    ld.setStopover(type, newStop);
+    ld.setTimestamp(type, now());
+    if (type == LiveData::Departure) {
+        ld.journey.setDeparture(newStop);
+    } else {
+        ld.journey.setArrival(newStop);
+    }
+    ld.journeyTimestamp = now();
+    ld.store(resId);
+
+    // update reservation with live data
+    const auto newRes = type == LiveData::Arrival ? PublicTransport::mergeArrival(res, newStop) : PublicTransport::mergeDeparture(res, newStop);
+    if (!ReservationHelper::equals(res, newRes)) {
+        m_resMgr->updateReservation(resId, newRes);
+    }
+
+    // emit update signals
+    Q_EMIT type == LiveData::Arrival ? arrivalUpdated(resId) : departureUpdated(resId);
+    Q_EMIT journeyUpdated(resId);
+
+    // check if we need to notify
+    if (NotificationHelper::shouldNotify(oldStop, newStop, type)) {
+        showNotification(resId, ld);
+    }
+}
+
 static void applyMissingJourneyData(KPublicTransport::JourneySection &journey, const KPublicTransport::JourneySection &oldJny)
 {
     if (journey.intermediateStops().size() != oldJny.intermediateStops().size()) {
@@ -382,8 +396,10 @@ void LiveDataManager::updateJourneyData(const KPublicTransport::JourneySection &
     ld.journey.applyMetaData(true); // download logo assets if needed
     ld.journeyTimestamp = now();
     ld.departure = ld.journey.departure();
+    ld.departure.addNotes(oldDep.notes());
     ld.departureTimestamp = now();
     ld.arrival = ld.journey.arrival();
+    ld.arrival.setNotes(oldArr.notes());
     ld.arrivalTimestamp = now();
     ld.store(resId, LiveData::AllTypes);
 
@@ -423,7 +439,7 @@ void LiveDataManager::fillNotification(KNotification* n, const LiveData& ld) con
 {
     n->setTitle(NotificationHelper::title(ld));
     n->setText(NotificationHelper::message(ld));
-    n->setIconName(QLatin1String("clock"));
+    n->setIconName(QLatin1StringView("clock"));
     if (m_showNotificationsOnLockScreen) {
         n->setHint(QStringLiteral("x-kde-visibility"), QStringLiteral("public"));
     }
@@ -768,7 +784,7 @@ void LiveDataManager::pkPassUpdated(const QString &passId, const QStringList &ch
                           LocationUtil::name(LocationUtil::arrivalLocation(passRes))));
     }
 
-    KNotification::event(KNotification::Notification, i18n("Itinerary change"), text, QLatin1String("clock"));
+    KNotification::event(KNotification::Notification, i18n("Itinerary change"), text, QLatin1StringView("clock"));
 }
 
 KPublicTransport::Manager* LiveDataManager::publicTransportManager() const
