@@ -7,9 +7,9 @@
 #ifndef TRIPGROUP_H
 #define TRIPGROUP_H
 
+#include <QList>
 #include <QMetaType>
 #include <QString>
-#include <QVector>
 
 class TripGroupManager;
 
@@ -22,19 +22,23 @@ class TripGroup
     Q_PROPERTY(QString name READ name)
     Q_PROPERTY(QDateTime beginDateTime READ beginDateTime)
     Q_PROPERTY(QDateTime endDateTime READ endDateTime)
+    Q_PROPERTY(QString slugName READ slugName)
 public:
     TripGroup();
     TripGroup(TripGroupManager *mgr);
     ~TripGroup();
 
-    QString name() const;
+    [[nodiscard]] QString name() const;
     void setName(const QString &name);
 
-    QVector<QString> elements() const;
-    void setElements(const QVector<QString> &elems);
+    [[nodiscard]] QList<QString> elements() const;
+    void setElements(const QList<QString> &elems);
 
-    QDateTime beginDateTime() const;
-    QDateTime endDateTime() const;
+    [[nodiscard]] QDateTime beginDateTime() const;
+    [[nodiscard]] QDateTime endDateTime() const;
+
+    /** URL slug variant of the name, for use in file names. */
+    [[nodiscard]] QString slugName() const;
 
     bool load(const QString &path);
     void store(const QString &path) const;
@@ -42,7 +46,7 @@ public:
 private:
     TripGroupManager *m_mgr = nullptr;
     QString m_name;
-    QVector<QString> m_elements;
+    QList<QString> m_elements;
 };
 
 Q_DECLARE_METATYPE(TripGroup)
