@@ -27,7 +27,7 @@ public:
     void setReservationManager(ReservationManager *resMgr);
     void setTransferManager(TransferManager *transferMgr);
 
-    QVector<QString> tripGroups() const;
+    QList<QString> tripGroups() const;
     TripGroup tripGroup(const QString &id) const;
     QString tripGroupIdForReservation(const QString &resId) const;
     TripGroup tripGroupForReservation(const QString &resId) const;
