@@ -78,12 +78,12 @@ QString Util::textToHtml(const QString& text)
 
 QString Util::telephoneUrl(const QString &phoneNumber)
 {
-    return QLatin1String("tel:") + KContacts::PhoneNumber(phoneNumber).normalizedNumber();
+    return QLatin1StringView("tel:") + KContacts::PhoneNumber(phoneNumber).normalizedNumber();
 }
 
 QString Util::emailUrl(const QString &emailAddress)
 {
-    return QLatin1String("mailto:") + emailAddress;
+    return QLatin1StringView("mailto:") + emailAddress;
 }
 
 void Util::sortModel(QObject *model, int column, Qt::SortOrder sortOrder)
@@ -122,4 +122,9 @@ bool Util::isDarkImage(const QImage &img)
     return darkCount > (SAMPLE_COUNT * SAMPLE_COUNT / 2);
 }
 
+QString Util::toBase64(const QByteArray &data)
+{
+    return QString::fromLatin1(data.toBase64());
+}
+
 #include "moc_util.cpp"
