@@ -8,7 +8,7 @@
 
 #include "android/calendardata.h"
 
-#include <kandroidextras/calendarcontract.h>
+#include "kandroidextras/calendarcontract.h"
 #include <KAndroidExtras/JniObject>
 
 #include <QCoreApplication>
@@ -25,13 +25,12 @@ AndroidCalendarPlugin::AndroidCalendarPlugin(QObject *parent, const QVariantList
 
 AndroidCalendarPlugin::~AndroidCalendarPlugin() = default;
 
-QVector<KCalendarCore::Calendar::Ptr> AndroidCalendarPlugin::calendars() const
-{
-    if (m_calendars.isEmpty()) {
-        loadCalendars();
-    }
+QList<KCalendarCore::Calendar::Ptr> AndroidCalendarPlugin::calendars() const {
+  if (m_calendars.isEmpty()) {
+    loadCalendars();
+  }
 
-    return m_calendars;
+  return m_calendars;
 }
 
 void AndroidCalendarPlugin::loadCalendars() const
